#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 managed
version:              1.0.11
visibility:           public
id:                   managed-1.0.11-2Pnugu46RECJRycwImdLZr
key:                  managed-1.0.11-2Pnugu46RECJRycwImdLZr
license:              BSD-3-Clause
copyright:            2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.

    The reason this package defines a specialized version of these types is to:

    * be more beginner-friendly,

    * simplify inferred types and error messages, and:

    * provide some additional type class instances that would otherwise be orphan
    instances

category:             Control
abi:                  55ed02450eccd6280692deb3a3fde23a
exposed:              True
exposed-modules:      Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs:          /usr/lib/ghc-9.6.6/site-local/managed-1.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/managed-1.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/managed-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-managed
hs-libraries:         HSmanaged-1.0.11-2Pnugu46RECJRycwImdLZr
depends:              base-4.18.2.1 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html:         /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

